@@ -19,6 +19,7 @@ from .ps_tools import compute_ps
 # Default SO attribution for tiles
 so_attribution = '&copy; <a href="https://simonsobservatory.org/">Simons Observatory</a>'
 
+
 # Generate default plotly colormap based on planck colormap
 def generate_default_colorscale(default="planck"):
     from pixell import colorize
@@ -121,7 +122,7 @@ class App:
             else:
                 for i, item in enumerate(data_type):
                     name = "{} - {} - {}".format(tiles.get("prefix", "CMB"), map_id, item)
-                    url = "files/" + os.path.join(path, fits, "{z}/tile_{y}_{x}_%s.png" % i)
+                    url = os.path.join("files", path, fits, "{z}/tile_{y}_{x}_%s.png" % i)
                     self.layers.append(
                         ColorizableTileLayer(
                             url=url,
@@ -218,13 +219,15 @@ class App:
         self.m.add_control(WidgetControl(widget=cmap, position="bottomright"))
 
     def _add_theory(self):
+        plot_config = self.config.get("plot", dict())
         clth = {}
         lth, clth["TT"], clth["EE"], clth["BB"], clth["TE"] = np.loadtxt(
-            "bode_almost_wmap5_lmax_1e4_lensedCls_startAt2.dat", unpack=True
+            plot_config.get("theory", "bode_almost_wmap5_lmax_1e4_lensedCls_startAt2.dat"),
+            unpack=True,
         )
         clth["ET"] = clth["TE"]
         for spec in ["EB", "BE", "BT", "TB"]:
-            clth[spec] = clth["TE"] * 0
+            clth[spec] = clth["TE"] * 0.0
         self.theory = {"lth": lth, "clth": clth}
 
     def _add_plot(self):
@@ -280,7 +283,7 @@ class App:
             min=0,
             max=10000,
             step=100,
-            description="$\ell_\mathrm{max}$",
+            description=r"$\ell_\mathrm{max}$",
         )
         self.bin_size = widgets.IntSlider(
             value=plot_config.get("bin size", 40), min=0, max=100, step=10, description="Bin size",
@@ -432,15 +435,15 @@ class App:
                     text="{} - {}".format(split_name, patch_name),
                     font=dict(color=qualitative.Plotly[list(self.patches).index(patch_name)]),
                 ),
-                xaxis_title="$\ell_X$",
-                yaxis_title="$\ell_Y$",
+                xaxis_title=r"$\ell_X$",
+                yaxis_title=r"$\ell_Y$",
                 coloraxis={"colorscale": default_colorscale},
             )
             self.fig.add_heatmap(z=powermap, coloraxis="coloraxis")
 
         else:
             self.fig.update_layout(
-                title=split_name, xaxis_title="$\ell$", yaxis_title="$D_\ell^\mathrm{%s}$" % spec,
+                title=split_name, xaxis_title=r"$\ell$", yaxis_title=r"$D_\ell^\mathrm{%s}$" % spec,
             )
 
             for name, patch in self.patches.items():
